@@ -39,8 +39,7 @@ compute_posterior_intervals <- function(model_fit, burnin = model_fit$burnin,
   stopifnot(class(model_fit) == "BayesMallows")
 
   if(is.null(burnin)){
-    stop("Please specify the burnin, either by setting x$burnin or
-         as an argument to the plot.BayesMallows function.")
+    stop("Please specify the burnin.")
   }
 
   stopifnot(burnin < model_fit$nmc)
